package com.caimei365.manager.controller.hehe.product;


import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.hehe.product.*;
import com.caimei365.manager.service.hehe.product.HeHeProductService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@RestController
@RequestMapping("/HeHe")
public class HeHeProductApi {

    @Resource
    private HeHeProductService productService;

    /**
     * 商品管理
     *
     * @param product
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/product/list")
    public ResponseJson<PaginationVo<HeHeProduct>> userList(HeHeProduct product, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return productService.productList(product, pageNum, pageSize);
    }

    /**
     * 商品分类管理
     *
     * @param type
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/product/bigType")
    public ResponseJson<PaginationVo<HeHeBigType>> getBigType(HeHeBigType type, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return productService.bigTypeList(type, pageNum, pageSize);
    }

    /**
     * 商城活动列表
     *
     * @param activity
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/product/active")
    public ResponseJson<PaginationVo<HeHeActivity>> getActiveList(HeHeActivity activity, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return productService.activeList(activity, pageNum, pageSize);
    }

    /**
     * 限时特价活动列表
     *
     * @param activity
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/discount/activity")
    public ResponseJson<PaginationVo<DiscountActivity>> getActive(DiscountActivity activity, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return productService.discountActiveList(activity, pageNum, pageSize);
    }

    /**
     * 分享减免活动列表
     *
     * @param reduction
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/reduction/list")
    public ResponseJson<PaginationVo<ShareReduction>> getReduction(ShareReduction reduction, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return productService.shareReductionList(reduction, pageNum, pageSize);
    }

    /**
     * 内部优惠列表
     *
     * @param discount
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/inside/discount")
    public ResponseJson<PaginationVo<InsideDiscount>> insideDiscount(InsideDiscount discount, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return productService.insideDiscountList(discount, pageNum, pageSize);
    }

    /**
     * 拼团商品列表
     *
     * @param collage
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/collage/product")
    public ResponseJson<PaginationVo<CollageProduct>> CollageProductList(CollageProduct collage, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return productService.CollageProductList(collage, pageNum, pageSize);
    }

    /**
     * 拼团记录列表
     *
     * @param collage
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/collage/record")
    public ResponseJson<PaginationVo<CollageRecord>> CollageRecordList(CollageRecord collage, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return productService.CollageRecordList(collage, pageNum, pageSize);
    }

    /**
     * 分销者活动商品列表
     *
     * @param product
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/sales/products")
    public ResponseJson<PaginationVo<HeHeActivityProduct>> salesProductList(HeHeActivityProduct product, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        if (null == product.getUserId() || 0 == product.getUserId()) {
            return ResponseJson.error("分销者Id不能为空！", null);
        }
        return productService.salesProductList(product, pageNum, pageSize);
    }

    /**
     * 分销者添加活动商品弹窗列表
     * 商品取自呵呵活动商品
     *
     * @param userId
     * @param name
     * @param shopName
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/sales/activity/products")
    public ResponseJson<PaginationVo<HeHeProduct>> salesActivityProductList(String name, Integer userId, String shopName, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum, @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        if (null == userId || 0 == userId) {
            return ResponseJson.error("分销者Id不能为空！", null);
        }
        return productService.salesActivityProductList(name, userId, shopName, pageNum, pageSize);
    }

    /**
     * 商品管理 - 上线商品编辑页面参数
     * 商品一级分类
     *
     * @return
     */
    @GetMapping("/products/bigType")
    public ResponseJson<List<HeHeBigType>> findBigType() {
        return productService.findBigType();
    }

    /**
     * 商品管理 - 上线商品编辑页面参数
     * 商品二级分类
     * @param bigTypeId
     * @return
     */
    @GetMapping("/products/smallType")
    public ResponseJson<List<CmSmalltype>> findSmallType(Integer bigTypeId) {
        return productService.findSmallTypeList(bigTypeId);
    }

    /**
     * 商品管理 - 上线商品编辑页面参数
     * 商品活动
     * @return
     */
    @GetMapping("/products/activity")
    public ResponseJson<List<HeHeActivity>> findProductActivity() {
        return productService.findProductActivity();
    }

    /**
     * 商品管理 - 上线商品编辑页面参数
     * 选择商品列表
     * @param product
     * @return
     */
    @GetMapping("/products/productPage")
    public ResponseJson<List<HeHeProduct>> choseProductPage(HeHeProduct product) {
        return productService.choseProductPage(product);
    }


    @PostMapping("/product/save")
    public ResponseJson saveProduct(HeHeProduct product) {
        return productService.saveProduct(product);
    }
}
