package com.caimei365.manager.controller.hehe.user;

import com.caimei.utils.StringUtils;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.hehe.product.SalesProductDto;
import com.caimei365.manager.entity.hehe.user.HeHeUser;
import com.caimei365.manager.service.hehe.user.HeHeUserService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * @author zzj
 */
@RestController
@RequestMapping("/HeHe")
public class HeHeUserApi {

    @Resource
    private HeHeUserService userService;

    /**
     * 分销者列表
     *
     * @param man
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/sales/list")
    public ResponseJson<PaginationVo<HeHeUser>> salesList(HeHeUser man,
                                                          @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                          @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return userService.SalesList(man, pageNum, pageSize);
    }

    /**
     * 呵呵用户列表
     *
     * @param man
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/user/list")
    public ResponseJson<PaginationVo<HeHeUser>> userList(HeHeUser man,
                                                         @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                         @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return userService.userList(man, pageNum, pageSize);
    }

    /**
     * 添加/编辑分销者
     *
     * @param man
     * @return
     */
    @PostMapping("/save/sales")
    public ResponseJson saveSales(HeHeUser man) {
        if (StringUtils.isBlank(man.getName())) {
            return ResponseJson.error("姓名不能为空！");
        }
        if (StringUtils.isBlank(man.getMobile())) {
            return ResponseJson.error("手机号不能为空！");
        }
        return userService.saveSales(man);
    }

    /**
     * 添加分销者活动商品
     *
     * @param dto
     * @return
     */
    @PostMapping("/add/sales/products")
    public ResponseJson addSalesActivityProduct(SalesProductDto dto) {
        if (null == dto.getUserId()) {
            return ResponseJson.error("用户Id不能为空！");
        }
        if (StringUtils.isBlank(dto.getProductIds())) {
            return ResponseJson.error("商品Id不能为空！");
        }
        return userService.addSaleActivityProducts(dto.getUserId(), dto.getProductIds());
    }

    /**
     * 删除分销者活动商品
     *
     * @param dto
     * @return
     */
    @PostMapping("/del/sales/products")
    public ResponseJson delSalesActivityProduct(SalesProductDto dto) {
        if (null == dto.getUserId()) {
            return ResponseJson.error("用户Id不能为空！");
        }
        if (null == dto.getProductId()) {
            return ResponseJson.error("商品Id不能为空！");
        }
        return userService.delSaleActivityProducts(dto.getUserId(), dto.getProductId());
    }
}
