package com.caimei365.manager.service.hehe.product.impl;


import com.caimei.utils.AppUtils;
import com.caimei.utils.MathUtil;
import com.caimei.utils.StringUtil;
import com.caimei365.manager.config.thinkgem.Global;
import com.caimei365.manager.dao.hehe.HeHeProductDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.svip.CmSku;
import com.caimei365.manager.entity.hehe.product.*;
import com.caimei365.manager.service.hehe.product.HeHeProductService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

@Service
@Slf4j
public class HeHeProductServiceImpl implements HeHeProductService {

    @Autowired
    private HeHeProductDao productDao;

    @Override
    public ResponseJson<PaginationVo<HeHeProduct>> productList(HeHeProduct product, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<HeHeProduct> list = productDao.findProductList(product);
        String wwwServer = Global.getConfig("wwwServer");
        list.forEach(p -> {
            HeHeProduct cp = productDao.findProductElement(p.getProductId());
            p.setCostPrice(cp.getCostPrice());
            p.setShopPercent(cp.getShopPercent());
            p.setCostType(cp.getCostType());
            p.setPrice(cp.getPrice());
            //比例成本
            if ("2".equals(p.getCostType())) {
                BigDecimal costPrice = MathUtil.div(MathUtil.mul(p.getPrice(), p.getShopPercent()), 100, 2);
                p.setCostPrice(costPrice);
            }
            p.setMainImage(AppUtils.getImageURL("product", p.getMainImage(), 0, wwwServer));
        });
        PaginationVo<HeHeProduct> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<HeHeBigType>> bigTypeList(HeHeBigType type, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<HeHeBigType> list = productDao.findBigTypeList(type);
        PaginationVo<HeHeBigType> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<HeHeActivity>> activeList(HeHeActivity activity, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<HeHeActivity> list = productDao.findActivityList(activity);
        PaginationVo<HeHeActivity> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<DiscountActivity>> discountActiveList(DiscountActivity activity, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<DiscountActivity> list = productDao.findDiscountActivityList(activity);
        list.forEach(this::setActivityStatus);
        PaginationVo<DiscountActivity> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<ShareReduction>> shareReductionList(ShareReduction reduction, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ShareReduction> list = productDao.findShareReductionList(reduction);
        list.forEach(this::setShareReductionStatus);
        PaginationVo<ShareReduction> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<InsideDiscount>> insideDiscountList(InsideDiscount discount, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<InsideDiscount> list = productDao.findInsideDiscountList(discount);
        PaginationVo<InsideDiscount> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<CollageProduct>> CollageProductList(CollageProduct collage, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CollageProduct> list = productDao.findCollageProductList(collage);
        list.forEach(product -> {
            product.setProductImage(AppUtils.getImageURL("product", product.getProductImage(), 0, "https://www.caimei365.com/"));
        });
        PaginationVo<CollageProduct> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<CollageRecord>> CollageRecordList(CollageRecord collage, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CollageRecord> list = productDao.findCollageRecordList(collage);
        list.forEach(col -> {
            // 获取已拼团的订单id列表
            List<Integer> orderIdList = productDao.getCollageOrderIds(col.getId());
            col.setOrderIdList(orderIdList);
        });
        PaginationVo<CollageRecord> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<HeHeActivityProduct>> salesProductList(HeHeActivityProduct product, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<HeHeActivityProduct> productList = productDao.activityProductList(product);
        String wwwServer = Global.getConfig("wwwServer");
        productList.forEach(item -> {
            item.setSkus(getProductSku(item.getProductId()));
            if (StringUtil.isNotBlank(item.getMainImage())) {
                item.setMainImage(AppUtils.getImageURL("product", item.getMainImage(), 0, wwwServer));
            }
        });
        PaginationVo<HeHeActivityProduct> page = new PaginationVo<>(productList);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<HeHeProduct>> salesActivityProductList(String name, Integer userId, String shopName, int pageNum, int pageSize) {
        List<Integer> productIds = productDao.findUserActivityProduct(userId);
        PageHelper.startPage(pageNum, pageSize);
        HeHeProduct heHeProduct = new HeHeProduct();
        heHeProduct.setIds(productIds);
        heHeProduct.setName(name);
        heHeProduct.setShopName(shopName);
        /**
         * todo
         * 根据userId过滤已存在该分销的活动商品列表商品，有空改为一句sql
         */
        List<HeHeProduct> productList = productDao.findAllActivityProduct(heHeProduct);
        String wwwServer = Global.getConfig("wwwServer");
        productList.forEach(item -> {
            if (StringUtil.isNotBlank(item.getMainImage())) {
                item.setMainImage(AppUtils.getImageURL("product", item.getMainImage(), 0, wwwServer));
            }
        });
        PaginationVo<HeHeProduct> page = new PaginationVo<>(productList);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<List<HeHeBigType>> findBigType() {
        return ResponseJson.success(productDao.findBigTypeList(new HeHeBigType()));
    }

    @Override
    public ResponseJson<List<CmSmalltype>> findSmallTypeList(Integer bigTypeId) {
        return ResponseJson.success(productDao.findSmallTypeList(bigTypeId));
    }

    @Override
    public ResponseJson<List<HeHeActivity>> findProductActivity() {
        return ResponseJson.success(productDao.findActivityList(new HeHeActivity()));
    }

    @Override
    public ResponseJson<List<HeHeProduct>> choseProductPage(HeHeProduct product) {
        return ResponseJson.success(productDao.findProductPage(product));
    }

    @Override
    public ResponseJson saveProduct(HeHeProduct product) {
//        product.getProductId()
//        productDao.
        return null;
    }

    public void setShareReductionStatus(ShareReduction reduction) {
        Date date = new Date();
        SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        if (reduction != null) {
            try {
                if (date.compareTo(formatter.parse(reduction.getStartTime())) < 0) {
                    reduction.setStatus(1);
                } else if (date.compareTo(formatter.parse(reduction.getEndTime())) > 0) {
                    reduction.setStatus(3);
                } else {
                    reduction.setStatus(2);
                }
            } catch (ParseException e) {
                throw new RuntimeException(e);
            }
        }
    }

    public void setActivityStatus(DiscountActivity activity) {
        Date date = new Date();
        SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        if (activity != null) {
            try {
                if (date.compareTo(formatter.parse(activity.getOnlineTime())) < 0) {
                    activity.setStatus(1);
                } else if (date.compareTo(formatter.parse(activity.getOfflineTime())) > 0) {
                    activity.setStatus(3);
                } else {
                    activity.setStatus(2);
                }
            } catch (ParseException e) {
                throw new RuntimeException(e);
            }
        }
    }

    public List<CmSku> getProductSku(Integer productId) {
        List<CmSku> skuList = productDao.findHeHeSku(productId);
        skuList.forEach(s -> s.setLadderPriceList(productDao.findLadderList(s.getSkuId())));
        return skuList;
    }
}
